# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class EntitiesController < Hermes::Api::Dmo::ApplicationController
        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          ids
          als_id
          title
          siret
          siren
          is_root
          root_id
          automated_request_validations
          delegated_validations
          priorities_enabled
          in_peec
          achieved_goal
          spent_on_completed_requests
          spent_on_ongoing_requests
          spent_on_other
          annual_stock
          total_spent
          points_balance
          applicant_ids
          housing_offer_ids
          lessor_id
          group_id
          supervisor_group_id
          manager_group_id
          address
          postal_code
          district
          country
          latitude
          longitude
        ].freeze

        REGEX_PARAMS = %w[
        ].freeze

        MUTATE_PARAMS = %i[
          title
          siret
          siren
          is_root
          root_id
          automated_request_validations
          delegated_validations
          priorities_enabled
          in_peec
          achieved_goal
          spent_on_completed_requests
          spent_on_ongoing_requests
          spent_on_other
          annual_stock
          applicant_ids
          housing_offer_ids
          lessor_id
          address
          postal_code
          district
          country
          latitude
          longitude
        ].freeze
        mutate_params_only(*MUTATE_PARAMS)

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          @query_precision ||= {}
          if params[:housing_offer_ids]
            housing_entity_ids = Hermes::HousingEntityOffer.only(:id, :housing_offer_id)
                                                           .where(
                                                             housing_offer_id: params[:housing_offer_ids]
                                                           ).pluck(:id)
            @query_precision[:housing_entity_offer_ids] = housing_entity_ids
          end
          super
        end
      end
    end
  end
end
